# CodeGenPT
![Version](https://img.shields.io/pypi/v/codegenpt)
![Python Version Support](https://img.shields.io/pypi/pyversions/codegenpt)

Autogenerate files using ChatGPT API.

## Installation
```
pip install codegenpt
```

## Usage
CodeGenPT looks for `.codegenpt` files within the source tree and generate files using its instructions.

Example: `hello_world.py.codegenpt`
```
Create a hello world program
```

Then:
```bash
$ codegenpt helloworld.py.codegenpt
⏳ Generating file: helloworld.py
🍺 File generated: helloworld.py
🍻 Success
```

Will generate a file name `helloworld.py`:
```python
print("hello world");
```

The actual content of the file will be generated by ChatGPT, so it will vary at each run.

You can also recursevily generate all files within a directory:
```bash
$ codegenpt -R .
🔎 Searching files...
⏳ Generating file: helloworld.py
🍺 File generated: helloworld.py
⏳ Generating file: README.md
🍺 File generated: README.md
⏳ Generating file: tests/tests.py
🍺 File generated: tests/tests.py
🍻 Success
```

## Setup
CodeGenPT expects an environment variable called `OPEN_API_KEY`.

1. Get an [Open AI API Key](https://github.com/Significant-Gravitas/Auto-GPT#:~:text=Get%20an%20OpenAI-,API%20Key,-Download%20the%20latest)
2. Add the key to your `OPEN_API_KEY` environment variable:
  - If you use `bash`:
    ```bash
    echo 'export OPENAI_API_KEY={your api key}' >> ~/.bash_profile && source ~/.bash_profile
    ```
  - If yu use `zsh`:
    ```bash
    echo 'export OPENAI_API_KEY={your api key}' >> ~/.zshenv && source ~/.zshenv

## Commands
Commands are special instructions you can use to instruct the generation process.

All codegenpt commands are placed in a single line in the format:
```
@cogenpt.command_name args...
```

### @codegenpt.include
Includes one or more files on the context.
Included files can be referenced using `@filename.ext` in the generation instructions

Example: 

`names.txt`:
```
Diego
Alberto
Daniel
```

`random_name.js.codegenpt`:
```
@codegenpt.include assets/names.txt

Read @names.txt and write a function that returns one of the names
```

`random_name.js`:
```js
function getRandomName() {
  const names = [
    'Diego',
    'Alberto',
    'Daniel'
  ];

  const randomIndex = Math.floor(Math.random() * names.length);

  return names[randomIndex];
}
```
